/****************************************************
 * This file is generated by cmake.  Modify the top
 * level CMakeLists.txt to change the VERSION numbers
 ****************************************************/

#define VERSION_MAJOR 4
#define VERSION_MINOR 8
#define VERSION_PATCH 2
#define TLSH_HASH "compact hash"
#define TLSH_CHECKSUM "1 byte checksum"
